@@ -35,12 +35,12 @@ Mapper::Params Mapper::PRMS {
     max_events      : 30000,
     max_stay_frac   : 0.5,
     min_seed_prob   : -3.75,
-    evt_buffer_len  : 6000,
     evt_batch_size  : 5,
     evt_timeout     : 10.0,
     chunk_timeout   : 4000.0,
     bwa_prefix      : "",
     idx_preset      : "default",
+    model_path      : "",
     seed_prms       : SeedTracker::PRMS_DEF,
     norm_prms       : Normalizer::PRMS_DEF,
     event_prms      : EventDetector::PRMS_DEF,
@@ -66,6 +66,7 @@ u32 Mapper::PATH_TAIL_MOVE = 0;
 Mapper::Mapper() :
     evdt_(PRMS.event_prms),
     evt_prof_(PRMS.evt_prof_prms),
+    norm_(PRMS.norm_prms),
     seed_tracker_(PRMS.seed_prms),
     state_(State::INACTIVE) {
 
@@ -109,6 +110,10 @@ void Mapper::load_static() {
 
     if (fmi.is_loaded()) return;
 
+    if (!PRMS.model_path.empty()) {
+        model = PoreModel<KLEN>(PRMS.model_path, true);
+    }
+
     fmi.load_index(PRMS.bwa_prefix);
     if (!fmi.is_loaded()) {
         std::cerr << "Error: failed to load BWA index\n";
@@ -218,6 +223,7 @@ void Mapper::reset() {
     last_chunk_ = false;
     state_ = State::MAPPING;
     norm_.skip_unread();
+    //norm_.reset();
 
     seed_tracker_.reset();
     evdt_.reset();
@@ -375,10 +381,12 @@ bool Mapper::chunk_mapped() {
 bool Mapper::map_chunk() {
     wait_time_ += map_timer_.lap();
 
-    if (reset_ || chunk_timer_.get() > PRMS.chunk_timeout) {
+    if (reset_ || 
+        chunk_timer_.get() > PRMS.chunk_timeout ||
+        event_i_ >= PRMS.max_events) {
+
         set_failed();
         read_.loc_.set_ended();
-        //std::cerr << "# END timer or reset\n";
         return true;
 
     } else if (norm_.empty() && 
@@ -646,7 +654,7 @@ bool Mapper::map_next() {
         #endif
     }
 
-    dbg_conf_out();
+    //dbg_conf_out();
 
     //Update event index
     event_i_++;
@@ -897,11 +905,11 @@ void Mapper::dbg_open_all() {
             << "win_mask\n";
         #endif
 
-        #ifdef DEBUG_CONFIDENCE
-        dbg_open(conf_out_, "_conf.tsv");
-        conf_out_ << "top_conf\t"
-                  << "mean_conf\n";
-        #endif
+        //#ifdef DEBUG_CONFIDENCE
+        //dbg_open(conf_out_, "_conf.tsv");
+        //conf_out_ << "top_conf\t"
+        //          << "mean_conf\n";
+        //#endif
 
         dbg_opened_ = true;
     }
@@ -936,26 +944,26 @@ void Mapper::dbg_close_all() {
         if (events_out_.is_open()) events_out_.close();
         #endif
 
-        #ifdef DEBUG_CONFIDENCE
-        if (conf_out_.is_open()) conf_out_.close();
-        #endif
+        ///#ifdef DEBUG_CONFIDENCE
+        ///if (conf_out_.is_open()) conf_out_.close();
+        ///#endif
 
         dbg_opened_ = false;
     }
     #endif
 }
 
-void Mapper::dbg_conf_out() {
-    #ifdef DEBUG_CONFIDENCE
-    if (seed_tracker_.empty() || seed_tracker_.get_top_conf() == 0) return;
-    conf_out_ << evt_prof_.mask_idx_map_[event_i_] << "\t"
-              << seed_tracker_.get_best().id_ << "\t"
-              << seed_tracker_.get_top_conf() << "\t"
-              << seed_tracker_.get_mean_conf() << "\n";
-
-    conf_out_.flush();
-    #endif
-}
+//void Mapper::dbg_conf_out() {
+//    #ifdef DEBUG_CONFIDENCE
+//    if (seed_tracker_.empty() || seed_tracker_.get_top_conf() == 0) return;
+//    conf_out_ << evt_prof_.mask_idx_map_[event_i_] << "\t"
+//              << seed_tracker_.get_best().id_ << "\t"
+//              << seed_tracker_.get_top_conf() << "\t"
+//              << seed_tracker_.get_mean_conf() << "\n";
+//
+//    conf_out_.flush();
+//    #endif
+//}
 
 void Mapper::dbg_events_out() {
     #ifdef DEBUG_EVENTS
@@ -1007,14 +1015,6 @@ void Mapper::dbg_seeds_out(
     u64 ref_st = 0;
     fmi.translate_loc(sa_half, rf_name, ref_st);
 
-    if (ref_st == 0) {
-        std::cerr << rf_name << "\t"
-                  << sa_start << "\t"
-                  << sa_half << "\t"
-                  << static_cast<int>(path.type_head()) << "\t"
-                  << static_cast<int>(path.type_tail()) << "\n";
-    }
-
     seeds_out_ << rf_name << "\t"
                << ref_st << "\t"
                << (ref_st + ref_len) << "\t"
